// src/index.tsx
import { useEffect, useRef } from "react";
import { loop } from "sketch-loop";
import { jsx } from "react/jsx-runtime";
function SketchLoop({ onTick, onResize, onInteraction }) {
  const ref = useRef(null);
  useEffect(() => {
    if (ref == null || ref.current == null) {
      return;
    }
    const app = loop({
      canvas: ref.current
    });
    app.on({
      type: "tick",
      action: onTick
    });
    if (onResize != null) {
      app.on({
        type: "resize",
        action: onResize
      });
    }
    if (onInteraction != null) {
      let createInteractionEvent2 = function(type) {
        return function onInteractionEvent(args) {
          if (onInteraction != null) {
            onInteraction({
              type,
              ...args
            });
          }
        };
      };
      var createInteractionEvent = createInteractionEvent2;
      app.on({
        type: "pointerdown",
        action: createInteractionEvent2("pointerdown")
      });
      app.on({
        type: "pointermove",
        action: createInteractionEvent2("pointermove")
      });
      app.on({
        type: "pointerup",
        action: createInteractionEvent2("pointerup")
      });
    }
    app.start();
    return () => {
      app.dispose();
    };
  }, [ref, onTick, onInteraction, onResize]);
  return /* @__PURE__ */ jsx("canvas", { ref });
}
export {
  SketchLoop
};
